@@ -3,11 +3,12 @@ WSTApplicationDelegateClass
 
 An instance of this class is instantiated in the MainMenu.nib default NIB file.
 """
-from Cocoa import *
+import objc
+from Cocoa import NSObject
 from WSTConnectionWindowControllerClass import WSTConnectionWindowController
 
-class WSTApplicationDelegate(NSObject):
 
+class WSTApplicationDelegate(NSObject):
     @objc.IBAction
     def newConnectionAction_(self, sender):
         """Action method fired when the user selects the 'new connection'
