@@ -5,6 +5,11 @@ for the document windows for the Web Services Tool application.
 Implements a standard toolbar.
 """
 
+import string
+import types
+
+import Cocoa
+
 # Note about multi-threading.
 # Although WST does its network stuff in a background thread, with Python 2.2
 # there are still moments where the app appears to hang briefly. This should
@@ -15,19 +20,9 @@ Implements a standard toolbar.
 # Python would not grant time to other threads while blocking inside
 # getaddrinfo(). This has been fixed *after* 2.3b1 was released. (jvr)
 import objc
-import Cocoa
-
 from twisted.internet import defer
 from twisted.web.xmlrpc import Proxy
 
-import sys
-import types
-import string
-import traceback
-
-# from twisted.python import log
-# log.startLogging(sys.stdout)
-
 kWSTReloadContentsToolbarItemIdentifier = "WST: Reload Contents Toolbar Identifier"
 """Identifier for 'reload contents' toolbar item."""
 
@@ -400,7 +395,9 @@ class WSTConnectionWindowController(Cocoa.NSWindowController):
         if not len(methodSignature):
             return
         for aSignature in methodSignature:
-            if (type(aSignature) == types.ListType) and (len(aSignature) > 0):
+            if (type(aSignature) == types.ListType) and (
+                len(aSignature) > 0
+            ):  # noqa: E721
                 signature = "%s %s(%s)" % (
                     aSignature[0],
                     aMethod,
@@ -479,7 +476,7 @@ class WSTConnectionWindowController(Cocoa.NSWindowController):
         depending on if a signature had been found on the server.
         """
         aMethod = self._methods[rowIndex]
-        if self._methodSignatures.has_key(aMethod):
+        if aMethod in self._methodSignatures:
             return self._methodSignatures[aMethod]
         else:
             return aMethod
